"""Tests for plugin and/or channel specific tasks"""

import os
import unittest
from types import SimpleNamespace
from plugins.channels import channels
from plugins import CHANNEL_ROOT_CACHE
from user.user import create_json_file, empty_json_file


class TestChannelRootEnvVarReplacement(unittest.TestCase):

    channel = "Pirates"
    launcher = SimpleNamespace(**{"hpc_variables": {
        "$HOME": "/p/home/jsparrow",
        "$PROJECTS_HOME": "/p/projects",
        "$WORKDIR": "/p/work1/jsparrow"
    }}) # A gimmicked InterfaceLauncher

    def test_basic_home_replacement(self):
        channel_root = "/p/home/jsparrow/test/black-pearl-plugin-channel"
        replaced = "$HOME/test/black-pearl-plugin-channel"
        assert replaced == channels.update_channel_root(self.launcher, channel_root, self.channel)

    def test_basic_projects_home_replacement(self):
        channel_root = "/p/projects/black_pearl/black-pearl-plugin-channel"
        replaced = "$PROJECTS_HOME/black_pearl/black-pearl-plugin-channel"
        assert replaced == channels.update_channel_root(self.launcher, channel_root, self.channel)

    def test_basic_workdir_replacement(self):
        channel_root = "/p/work1/jsparrow/black-pearl-plugin-channel"
        replaced = "$WORKDIR/black-pearl-plugin-channel"
        assert replaced == channels.update_channel_root(self.launcher, channel_root, self.channel)

    def test_multi_replace_issue(self):
        # /p/home/jsparrow should not be replaced
        channel_root = "/p/projects/p/home/jsparrow/black_pearl/black-pearl-plugin-channel"
        replaced = "$PROJECTS_HOME/p/home/jsparrow/black_pearl/black-pearl-plugin-channel"
        assert replaced == channels.update_channel_root(self.launcher, channel_root, self.channel)

    def test_no_replacement(self):
        channel_root = "/tmp/black_pearl/black-pearl-plugin-channel"
        replaced = "/tmp/black_pearl/black-pearl-plugin-channel"
        assert replaced == channels.update_channel_root(self.launcher, channel_root, self.channel)

class TestChannelRootCacheFile(unittest.TestCase):

    cache = "/tmp/channel_root_cache.json"

    @classmethod
    def setUpClass(cls):
        channels.CHANNEL_ROOT_CACHE = cls.cache
        create_json_file(cls.cache)

    @classmethod
    def tearDownClass(cls):
        channels.CHANNEL_ROOT_CACHE = CHANNEL_ROOT_CACHE
        os.remove(cls.cache)

    def setUp(self):
        empty_json_file(self.cache)

    def test_write_cache(self):
        channels.write_channel_root_to_cache("test", "$HOME/test")
        assert channels.get_channel_root_from_cache("test") == "$HOME/test"

    def test_update_existing_channel(self):
        self.test_write_cache()
        channels.write_channel_root_to_cache("test", "$HOME/test2")
        assert channels.get_channel_root_from_cache("test") == "$HOME/test2"

    def test_no_item_in_cache(self):
        assert channels.get_channel_root_from_cache("test") == ""

    def test_remove_item_from_cache(self):
        self.test_write_cache()
        channels.remove_channel_root_from_cache("test")
        assert channels.get_channel_root_from_cache("test") == ""
